==> prestashop_1.5.0.9.zip: prestashop/modules/homeslider/translations/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{homeslider}prestashop>homeslider_693b83f5eca43e2bb1675287c37ce9e2'] = 'Carousel d\'image (slider) pour votre page d\'accueil';
$_MODULE['<{homeslider}prestashop>homeslider_c17aed434289cedd02618451e12c8da6'] = 'Ajouter un carousel d\'images à votre page d\'accueil';
$_MODULE['<{homeslider}prestashop>homeslider_17167898123700e4b4f9bc17c1e0608d'] = 'Configuration du carousel';
$_MODULE['<{homeslider}prestashop>homeslider_e933dc24fb245d863a43b4fefe9b45f5'] = 'Hauteur :';
$_MODULE['<{homeslider}prestashop>homeslider_48ccf48dcf2218a413ce473262f21a0c'] = 'Largeur :';
$_MODULE['<{homeslider}prestashop>homeslider_2c526c645bca9542ba1598835d46b753'] = 'Vitesse :';
$_MODULE['<{homeslider}prestashop>homeslider_154e6bcf4e3b49a424323cb9021ef851'] = 'Pause :';
$_MODULE['<{homeslider}prestashop>homeslider_9ce04a5715756f9c0fece348db9b7da1'] = 'Boucle : ';
$_MODULE['<{homeslider}prestashop>homeslider_93cba07454f06a4a960172bbd6e2a435'] = 'Oui';
$_MODULE['<{homeslider}prestashop>homeslider_bafd7322c6e97d25b6299b5d6fe8920b'] = 'Non';
$_MODULE['<{homeslider}prestashop>homeslider_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{homeslider}prestashop>homeslider_571988492824e57070d78e6c86333f20'] = 'Configuration d\'une diapositive';
$_MODULE['<{homeslider}prestashop>homeslider_02023fc24279454047fd419ecd1db9af'] = 'Ajouter une diapositive';
$_MODULE['<{homeslider}prestashop>homeslider_a9884c8f5501dc36b3ae14a380f0013f'] = 'Vous n\'avez pas encore ajouté de diapositive.';
$_MODULE['<{homeslider}prestashop>homeslider_7dce122004969d56ae2e0245cb754d35'] = 'Modifier';
$_MODULE['<{homeslider}prestashop>homeslider_f2a6c498fb90ee345d997f888fce3b18'] = 'Supprimer';
$_MODULE['<{homeslider}prestashop>homeslider_3b21e9521eb7b13b5e33325a4a06ae55'] = 'les modules %s doivent être accessible en écriture (CHMOD 755 / 777)';
$_MODULE['<{homeslider}prestashop>homeslider_947c5b1ecd3021f44ae45bc176085ae1'] = 'Mettre en ligne votre diapositive';
$_MODULE['<{homeslider}prestashop>homeslider_a5220b3d801e803e8c4133edcd0dc7b4'] = 'Sélectionner un fichier :';
$_MODULE['<{homeslider}prestashop>homeslider_2d806bd95ceb6d3166fb5c01d3fb75f0'] = 'Configurer votre diapositive';
$_MODULE['<{homeslider}prestashop>homeslider_32bd52059351cd9ac4ae44f16746da11'] = 'Modifier votre diapositive';
$_MODULE['<{homeslider}prestashop>homeslider_51ec9bf4aaeab1b25bb57f9f8d4de557'] = 'Titre :';
$_MODULE['<{homeslider}prestashop>homeslider_3b3d06023f6353f8fd05f859b298573e'] = 'URL :';
$_MODULE['<{homeslider}prestashop>homeslider_8046c95f98fc714db47978092bb24264'] = 'Légende :';
$_MODULE['<{homeslider}prestashop>homeslider_d0042a700e9bdf79689d63ee6846dc0e'] = 'Description :';
$_MODULE['<{homeslider}prestashop>homeslider_3d091e856cb7615d1ccb96bc759b5a92'] = 'Active :';
$_MODULE['<{homeslider}prestashop>homeslider_ea4788705e6873b424c65e91c2846b19'] = 'Annuler';
$_MODULE['<{homeslider}prestashop>homeslider_70397c4b252a5168c5ec003931cea215'] = 'Champs requis';
$_MODULE['<{homeslider}prestashop>homeslider_3f80dc2cdd06939d4f5514362067cd86'] = 'Valeur non valables';
$_MODULE['<{homeslider}prestashop>homeslider_a6abafe564d3940cc36ee43e2f09400b'] = 'Diapositive non valable';
$_MODULE['<{homeslider}prestashop>homeslider_b3e3ed438fb0ea2935b3e79eac1f1658'] = 'État non valable';
$_MODULE['<{homeslider}prestashop>homeslider_57b620e0495c07c15deda4dde882d47b'] = 'Position non valable pour la diapositive';
$_MODULE['<{homeslider}prestashop>homeslider_76ad3ac84a702b0497cd6be8e8886d34'] = 'ID non valable';
$_MODULE['<{homeslider}prestashop>homeslider_2f6e2bf88137020c30bdbf4ebe233c77'] = 'Titre trop long';
$_MODULE['<{homeslider}prestashop>homeslider_3b77d63253ad17dd30fd10e36d328517'] = 'Légence trop longue';
$_MODULE['<{homeslider}prestashop>homeslider_5f9058e4bbbf4dcdd556a16ad835431c'] = 'URL trop longue';
$_MODULE['<{homeslider}prestashop>homeslider_4b43a83204d657042170834b817269e4'] = 'Description trop longue';
$_MODULE['<{homeslider}prestashop>homeslider_c99b9ff9028266c00a8cf4aeae4b532f'] = 'Format d\'URL incorrect';
$_MODULE['<{homeslider}prestashop>homeslider_7a92ef6b168d77ebcdad785b01d77a8e'] = 'Nom de fichier non valable';
$_MODULE['<{homeslider}prestashop>homeslider_ff44e46af4fae17a4b7aea06a78432d8'] = 'Titre absent';
$_MODULE['<{homeslider}prestashop>homeslider_fbd5d9eaf858d277768f72f551d0e429'] = 'Légende absente';
$_MODULE['<{homeslider}prestashop>homeslider_96d7de12ec9cae5887bd18348c9e1b64'] = 'URL absente';
$_MODULE['<{homeslider}prestashop>homeslider_82bc69b4b2f634b51aea683457829cda'] = 'Image absente';
$_MODULE['<{homeslider}prestashop>homeslider_f6452628a4c8b6e97f8d447ebbfded1b'] = 'La configuration n\'a pas pu être mise à jour';
$_MODULE['<{homeslider}prestashop>homeslider_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configuration mise à jour';
$_MODULE['<{homeslider}prestashop>homeslider_07b8c09e490f7afbdcfa9cd5bfcfd4a9'] = 'Une erreur est survenue durant l\'envoi de l\'image';
$_MODULE['<{homeslider}prestashop>homeslider_f7e1d2ff3588d24a4b5a4f5af076123e'] = 'La diapositive n\'a pas pu être ajoutée';
$_MODULE['<{homeslider}prestashop>homeslider_917d4e296eddb76a6d0b6b908cbc1886'] = 'La diapositive n\'a pas pu être mise à jour';
$_MODULE['<{homeslider}prestashop>homeslider_5da12d1bb63af9cd5be306102b23e82e'] = 'Diapositive supprimée';
$_MODULE['<{homeslider}prestashop>homeslider_080b5727c047ef6658591f7d4507e681'] = 'Diapositive mise à jour';
$_MODULE['<{homeslider}prestashop>homeslider_bb6abf21a6c70c5740d93093b5518954'] = 'Diapositive ajoutée';
$_MODULE['<{homeslider}prestashop>homeslider_b9f5c797ebbf55adccdd8539a65a0241'] = 'Désactivé';
$_MODULE['<{homeslider}prestashop>homeslider_00d23a76e43b46dae9ec7aa9dcbebb32'] = 'Activé';

==> prestashop_1.5.2.0.zip: prestashop/modules/homeslider/translations/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{homeslider}prestashop>homeslider_693b83f5eca43e2bb1675287c37ce9e2'] = 'Carrousel d\'image (slider) pour votre page d\'accueil';
$_MODULE['<{homeslider}prestashop>homeslider_c17aed434289cedd02618451e12c8da6'] = 'Ajouter un carrousel d\'images à votre page d\'accueil';
$_MODULE['<{homeslider}prestashop>homeslider_17167898123700e4b4f9bc17c1e0608d'] = 'Configuration du carrousel';
$_MODULE['<{homeslider}prestashop>homeslider_e933dc24fb245d863a43b4fefe9b45f5'] = 'Hauteur :';
$_MODULE['<{homeslider}prestashop>homeslider_48ccf48dcf2218a413ce473262f21a0c'] = 'Largeur :';
$_MODULE['<{homeslider}prestashop>homeslider_2c526c645bca9542ba1598835d46b753'] = 'Vitesse :';
$_MODULE['<{homeslider}prestashop>homeslider_154e6bcf4e3b49a424323cb9021ef851'] = 'Pause :';
$_MODULE['<{homeslider}prestashop>homeslider_9ce04a5715756f9c0fece348db9b7da1'] = 'Boucle : ';
$_MODULE['<{homeslider}prestashop>homeslider_93cba07454f06a4a960172bbd6e2a435'] = 'Oui';
$_MODULE['<{homeslider}prestashop>homeslider_bafd7322c6e97d25b6299b5d6fe8920b'] = 'Non';
$_MODULE['<{homeslider}prestashop>homeslider_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{homeslider}prestashop>homeslider_571988492824e57070d78e6c86333f20'] = 'Configuration des diapositives';
$_MODULE['<{homeslider}prestashop>homeslider_02023fc24279454047fd419ecd1db9af'] = 'Ajouter une diapositive';
$_MODULE['<{homeslider}prestashop>homeslider_a9884c8f5501dc36b3ae14a380f0013f'] = 'Vous n\'avez pas encore ajouté de diapositive.';
$_MODULE['<{homeslider}prestashop>homeslider_7dce122004969d56ae2e0245cb754d35'] = 'Modifier';
$_MODULE['<{homeslider}prestashop>homeslider_f2a6c498fb90ee345d997f888fce3b18'] = 'Supprimer';
$_MODULE['<{homeslider}prestashop>homeslider_3b21e9521eb7b13b5e33325a4a06ae55'] = 'les modules %s doivent être accessible en écriture (CHMOD 755 / 777)';
$_MODULE['<{homeslider}prestashop>homeslider_947c5b1ecd3021f44ae45bc176085ae1'] = 'Mettre en ligne votre diapositive';
$_MODULE['<{homeslider}prestashop>homeslider_a5220b3d801e803e8c4133edcd0dc7b4'] = 'Sélectionner un fichier :';
$_MODULE['<{homeslider}prestashop>homeslider_2d806bd95ceb6d3166fb5c01d3fb75f0'] = 'Configurer votre diapositive';
$_MODULE['<{homeslider}prestashop>homeslider_32bd52059351cd9ac4ae44f16746da11'] = 'Modifier votre diapositive';
$_MODULE['<{homeslider}prestashop>homeslider_51ec9bf4aaeab1b25bb57f9f8d4de557'] = 'Titre :';
$_MODULE['<{homeslider}prestashop>homeslider_3b3d06023f6353f8fd05f859b298573e'] = 'URL :';
$_MODULE['<{homeslider}prestashop>homeslider_8046c95f98fc714db47978092bb24264'] = 'Légende :';
$_MODULE['<{homeslider}prestashop>homeslider_d0042a700e9bdf79689d63ee6846dc0e'] = 'Description :';
$_MODULE['<{homeslider}prestashop>homeslider_3d091e856cb7615d1ccb96bc759b5a92'] = 'Active :';
$_MODULE['<{homeslider}prestashop>homeslider_ea4788705e6873b424c65e91c2846b19'] = 'Annuler';
$_MODULE['<{homeslider}prestashop>homeslider_70397c4b252a5168c5ec003931cea215'] = 'Champs requis';
$_MODULE['<{homeslider}prestashop>homeslider_3f80dc2cdd06939d4f5514362067cd86'] = 'Valeur non valables';
$_MODULE['<{homeslider}prestashop>homeslider_a6abafe564d3940cc36ee43e2f09400b'] = 'Diapositive non valable';
$_MODULE['<{homeslider}prestashop>homeslider_b3e3ed438fb0ea2935b3e79eac1f1658'] = 'État non valable';
$_MODULE['<{homeslider}prestashop>homeslider_57b620e0495c07c15deda4dde882d47b'] = 'Position non valable pour la diapositive';
$_MODULE['<{homeslider}prestashop>homeslider_76ad3ac84a702b0497cd6be8e8886d34'] = 'ID non valable';
$_MODULE['<{homeslider}prestashop>homeslider_2f6e2bf88137020c30bdbf4ebe233c77'] = 'Titre trop long';
$_MODULE['<{homeslider}prestashop>homeslider_3b77d63253ad17dd30fd10e36d328517'] = 'Légence trop longue';
$_MODULE['<{homeslider}prestashop>homeslider_5f9058e4bbbf4dcdd556a16ad835431c'] = 'URL trop longue';
$_MODULE['<{homeslider}prestashop>homeslider_4b43a83204d657042170834b817269e4'] = 'Description trop longue';
$_MODULE['<{homeslider}prestashop>homeslider_c99b9ff9028266c00a8cf4aeae4b532f'] = 'Format d\'URL incorrect';
$_MODULE['<{homeslider}prestashop>homeslider_7a92ef6b168d77ebcdad785b01d77a8e'] = 'Nom de fichier non valable';
$_MODULE['<{homeslider}prestashop>homeslider_ff44e46af4fae17a4b7aea06a78432d8'] = 'Titre absent';
$_MODULE['<{homeslider}prestashop>homeslider_fbd5d9eaf858d277768f72f551d0e429'] = 'Légende absente';
$_MODULE['<{homeslider}prestashop>homeslider_96d7de12ec9cae5887bd18348c9e1b64'] = 'URL absente';
$_MODULE['<{homeslider}prestashop>homeslider_82bc69b4b2f634b51aea683457829cda'] = 'Image absente';
$_MODULE['<{homeslider}prestashop>homeslider_f6452628a4c8b6e97f8d447ebbfded1b'] = 'La configuration n\'a pas pu être mise à jour';
$_MODULE['<{homeslider}prestashop>homeslider_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configuration mise à jour';
$_MODULE['<{homeslider}prestashop>homeslider_07b8c09e490f7afbdcfa9cd5bfcfd4a9'] = 'Une erreur est survenue durant l\'envoi de l\'image';
$_MODULE['<{homeslider}prestashop>homeslider_f7e1d2ff3588d24a4b5a4f5af076123e'] = 'La diapositive n\'a pas pu être ajoutée';
$_MODULE['<{homeslider}prestashop>homeslider_917d4e296eddb76a6d0b6b908cbc1886'] = 'La diapositive n\'a pas pu être mise à jour';
$_MODULE['<{homeslider}prestashop>homeslider_5da12d1bb63af9cd5be306102b23e82e'] = 'Diapositive supprimée';
$_MODULE['<{homeslider}prestashop>homeslider_080b5727c047ef6658591f7d4507e681'] = 'Diapositive mise à jour';
$_MODULE['<{homeslider}prestashop>homeslider_bb6abf21a6c70c5740d93093b5518954'] = 'Diapositive ajoutée';
$_MODULE['<{homeslider}prestashop>homeslider_b9f5c797ebbf55adccdd8539a65a0241'] = 'Désactivé';
$_MODULE['<{homeslider}prestashop>homeslider_00d23a76e43b46dae9ec7aa9dcbebb32'] = 'Activé';
